@@ -35,7 +35,11 @@ jobWorkingDirectory=$1
 jobScratchDirectory=$2
 jobClass=$3
 
-rm -rf ${jobWorkingDirectory}
-exitStatus=$?
+sharedFileSystem=1
+
+if [ ${sharedFileSystem} -ne 1 ] ; then
+   rm -rf ${jobWorkingDirectory}
+   exitStatus=$?
+fi
 
 exit ${exitStatus}
