@@ -3,10 +3,10 @@
 # @package      hubzero-submit-distributor
 # @file         distributor.py
 # @author       Steven Clark <clarks@purdue.edu>
-# @copyright    Copyright 2004-2011 Purdue University. All rights reserved.
+# @copyright    Copyright 2004-2013 Purdue University. All rights reserved.
 # @license      http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
 #
-# Copyright (c) 2004-2013 HUBzero Foundation, LLC.
+# Copyright (c) 2004-2014 HUBzero Foundation, LLC.
 #
 # This file is part of: The HUBzero(R) Platform for Scientific Collaboration
 #
@@ -62,10 +62,14 @@
    """
 import os
 import sys
+import logging
+from logging.handlers import SocketHandler,SysLogHandler
 
 from hubzero.submit.JobDistributor import JobDistributor
 
-LOGDIRECTORY = os.path.join(os.sep,'var','log','submit','distributor')
+LOGDIRECTORY      = os.path.join(os.sep,'var','log','submit','distributor')
+HUBLOGFILE        = "distributor.log"
+APPLICATIONLOGGER = logging.getLogger('')
 
 CONFIGURATIONDIRECTORY = os.path.join(os.sep,'etc','submit')
 CONFIGURATIONFILE      = 'distributor.conf'
@@ -80,6 +84,32 @@ TUNNELMONITORPORT = 5729
 CLOUDMONITORHOST  = ""
 CLOUDMONITORPORT  = 5726
 
+def openLogger(logDirectory,
+               hubLogFile):
+   class EmptyFilter(logging.Filter):
+      """
+      This is a filter which rejects empty messages
+
+      """
+
+      def filter(self,record):
+         if record.getMessage() == "":
+            emptyRecord = True
+         else:
+            emptyRecord = False
+
+         return(not emptyRecord)
+
+   APPLICATIONLOGGER.setLevel(logging.DEBUG)
+
+   logSyslogHandler = SysLogHandler(address="/dev/log",facility=SysLogHandler.LOG_LOCAL6)
+   emptyFilter = EmptyFilter()
+   logSyslogHandler.addFilter(emptyFilter)
+   logFormatter = logging.Formatter('%(asctime)s %(message)s','%s [%a %b %d %H:%M:%S %Y]')
+   logSyslogHandler.setFormatter(logFormatter)
+   APPLICATIONLOGGER.addHandler(logSyslogHandler)
+
+
 def distributor(configFilePath,
                 logDirectory,
                 jobMonitorHost,jobMonitorPort,
@@ -100,6 +130,8 @@ def distributor(configFilePath,
 
 
 if __name__ == '__main__':
+   openLogger(LOGDIRECTORY,HUBLOGFILE)
+
    distributor(CONFIGFILEPATH,LOGDIRECTORY,
                JOBMONITORHOST,JOBMONITORPORT,
                PROBEMONITORHOST,PROBEMONITORPORT,
