@@ -1,10 +1,10 @@
 # @package      hubzero-submit-distributor
 # @file         RemoteBatchPBS.py
 # @author       Steven Clark <clarks@purdue.edu>
-# @copyright    Copyright (c) 2012-2013 HUBzero Foundation, LLC.
+# @copyright    Copyright (c) 2012-2014 HUBzero Foundation, LLC.
 # @license      http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
 #
-# Copyright (c) 2012-2013 HUBzero Foundation, LLC.
+# Copyright (c) 2012-2014 HUBzero Foundation, LLC.
 #
 # This file is part of: The HUBzero(R) Platform for Scientific Collaboration
 #
@@ -27,6 +27,7 @@
 
 import os.path
 import re
+import logging
 
 from hubzero.submit.TimeConversion import minTohhmmss
 
@@ -51,6 +52,7 @@ class RemoteBatchPBS:
                 wallTime,
                 quotaLimit,
                 timeHistoryLogs):
+      self.logger              = logging.getLogger(__name__)
       self.hubUserName         = hubUserName
       self.hubUserId           = hubUserId
       self.runName             = runName
@@ -98,7 +100,7 @@ class RemoteBatchPBS:
    def __makeSerialTemplate(self):
       return """#!/bin/sh
 #PBS -S /bin/sh
-#PBS -l nodes=NNODES:ATTRIBUTES:ppn=PPN
+#PBS -l nodes=NNODES:ppn=PPN:ATTRIBUTES
 #PBS -l walltime=WALLTIME
 #PBS -N JOB_JOBID_INSTANCEID
 #PBS -o pbs_RUNNAME_INSTANCEID.stdout
@@ -147,7 +149,7 @@ QUOTA
 date +"%s" > TS_START
 
 PREMANAGERCOMMANDS
-${TIMEPATH} -p -o TIME_RESULTS EXECUTABLE ARGUMENTS STDIN > RUNNAME_INSTANCEID.stdout 2> RUNNAME_INSTANCEID.stderr
+${TIMEPATH} --format "Command exited with status %x\\nreal %e\\nuser %U\\nsys %S" -o TIME_RESULTS EXECUTABLE ARGUMENTS STDIN > RUNNAME_INSTANCEID.stdout 2> RUNNAME_INSTANCEID.stderr
 POSTMANAGERCOMMANDS
 
 date +"%s" > TS_FINISH
@@ -226,7 +228,7 @@ date +"%s" > TS_FINISH
    def __makeMatlabMPITemplate(self):
       return """#!/bin/sh
 #PBS -S /bin/sh
-#PBS -l nodes=NNODES:ATTRIBUTES:ppn=PPN
+#PBS -l nodes=NNODES:ppn=PPN:ATTRIBUTES
 #PBS -l walltime=WALLTIME
 #PBS -N JOB_JOBID_INSTANCEID
 #PBS -o pbs_RUNNAME_INSTANCEID.stdout
@@ -267,7 +269,7 @@ for timePath in ${HOME}/bin/time /usr/bin/time /usr/local/bin/time /apps/submit/
    fi
 done
 
-export TIMERCOMMAND="${TIMEPATH} -p -a -o TIME_RESULTS"
+export TIMERCOMMAND="${TIMEPATH} --format "Command exited with status %x\\nreal %e\\nuser %U\\nsys %S" -a -o TIME_RESULTS"
 
 QUOTA
 
@@ -350,7 +352,7 @@ date +"%s" > TS_FINISH
    def __makeParallelTemplate(self):
       return """#!/bin/sh
 #PBS -S /bin/sh
-#PBS -l nodes=NNODES:ATTRIBUTES:ppn=PPN
+#PBS -l nodes=NNODES:ppn=PPN:ATTRIBUTES
 #PBS -l walltime=WALLTIME
 #PBS -N JOB_JOBID_INSTANCEID
 #PBS -o pbs_RUNNAME_INSTANCEID.stdout
@@ -402,7 +404,7 @@ QUOTA
 date +"%s" > TS_START
 
 PREMANAGERCOMMANDS
-${TIMEPATH} -p -o TIME_RESULTS MANAGERCOMMAND ${APPLICATION} ARGUMENTS STDIN > RUNNAME_INSTANCEID.stdout 2> RUNNAME_INSTANCEID.stderr
+${TIMEPATH} --format "Command exited with status %x\\nreal %e\\nuser %U\\nsys %S" -o TIME_RESULTS MANAGERCOMMAND ${APPLICATION} ARGUMENTS STDIN > RUNNAME_INSTANCEID.stdout 2> RUNNAME_INSTANCEID.stderr
 POSTMANAGERCOMMANDS
 
 date +"%s" > TS_FINISH
@@ -498,7 +500,7 @@ fi
    def __makeMPITemplate(self):
       return """#!/bin/sh
 #PBS -S /bin/sh
-#PBS -l nodes=NNODES:ATTRIBUTES:ppn=PPN
+#PBS -l nodes=NNODES:ppn=PPN:ATTRIBUTES
 #PBS -l walltime=WALLTIME
 #PBS -N JOB_JOBID_INSTANCEID
 #PBS -o pbs_RUNNAME_INSTANCEID.stdout
